@@ -41,12 +41,13 @@ module TZInfo
         c.timezone 'Antarctica/Davis', -823, 12, 2339, 30, 'Davis Station, Vestfold Hills'
         c.timezone 'Antarctica/Casey', -3977, 60, 6631, 60, 'Casey Station, Bailey Peninsula'
         c.timezone 'Antarctica/Vostok', -392, 5, 1069, 10, 'Vostok Station, S Magnetic Pole'
-        c.timezone 'Antarctica/DumontDUrville', -200, 3, 8401, 60, 'Dumont-d\'Urville Base, Terre Adelie'
+        c.timezone 'Antarctica/DumontDUrville', -200, 3, 8401, 60, 'Dumont-d\'Urville Station, Terre Adelie'
         c.timezone 'Antarctica/Syowa', -124211, 1800, 3959, 100, 'Syowa Station, E Ongul I'
       end
       country 'AR', 'Argentina' do |c|
         c.timezone 'America/Argentina/Buenos_Aires', -173, 5, -1169, 20, 'Buenos Aires (BA, CF)'
-        c.timezone 'America/Argentina/Cordoba', -157, 5, -3851, 60, 'most locations (CB, CC, CN, ER, FM, LP, MN, NQ, RN, SA, SE, SF, SL)'
+        c.timezone 'America/Argentina/Cordoba', -157, 5, -3851, 60, 'most locations (CB, CC, CN, ER, FM, LP, MN, NQ, RN, SA, SE, SF)'
+        c.timezone 'America/Argentina/San_Luis', -1999, 60, -1327, 20, 'San Luis (SL)'
         c.timezone 'America/Argentina/Jujuy', -1451, 60, -653, 10, 'Jujuy (JY)'
         c.timezone 'America/Argentina/Tucuman', -1609, 60, -3913, 60, 'Tucuman (TM)'
         c.timezone 'America/Argentina/Catamarca', -427, 15, -3947, 60, 'Catamarca (CT), Chubut (CH)'
@@ -73,10 +74,11 @@ module TZInfo
         c.timezone 'Australia/Lindeman', -304, 15, 149, 1, 'Queensland - Holiday Islands'
         c.timezone 'Australia/Adelaide', -419, 12, 1663, 12, 'South Australia'
         c.timezone 'Australia/Darwin', -187, 15, 785, 6, 'Northern Territory'
-        c.timezone 'Australia/Perth', -639, 20, 2317, 20, 'Western Australia'
+        c.timezone 'Australia/Perth', -639, 20, 2317, 20, 'Western Australia - most locations'
+        c.timezone 'Australia/Eucla', -1903, 60, 1933, 15, 'Western Australia - Eucla area'
       end
       country 'AW', 'Aruba' do |c|
-        c.timezone 'America/Aruba', 25, 2, -2069, 30
+        c.timezone 'America/Aruba', 25, 2, -2099, 30
       end
       country 'AX', 'Aaland Islands' do |c|
         c.timezone 'Europe/Mariehamn', 601, 10, 399, 20
@@ -111,6 +113,9 @@ module TZInfo
       country 'BJ', 'Benin' do |c|
         c.timezone 'Africa/Porto-Novo', 389, 60, 157, 60
       end
+      country 'BL', 'St Barthelemy' do |c|
+        c.timezone 'America/St_Barthelemy', 1073, 60, -1257, 20
+      end
       country 'BM', 'Bermuda' do |c|
         c.timezone 'Atlantic/Bermuda', 1937, 60, -1943, 30
       end
@@ -164,16 +169,17 @@ module TZInfo
         c.timezone 'America/Toronto', 873, 20, -4763, 60, 'Eastern Time - Ontario - most locations'
         c.timezone 'America/Nipigon', 2941, 60, -1324, 15, 'Eastern Time - Ontario & Quebec - places that did not observe DST 1967-1973'
         c.timezone 'America/Thunder_Bay', 2903, 60, -357, 4, 'Eastern Time - Thunder Bay, Ontario'
+        c.timezone 'America/Iqaluit', 956, 15, -1027, 15, 'Eastern Time - east Nunavut - most locations'
         c.timezone 'America/Pangnirtung', 992, 15, -986, 15, 'Eastern Time - Pangnirtung, Nunavut'
-        c.timezone 'America/Iqaluit', 956, 15, -1027, 15, 'Eastern Time - east Nunavut'
+        c.timezone 'America/Resolute', 33613, 450, -22759, 240, 'Eastern Time - Resolute, Nunavut'
         c.timezone 'America/Atikokan', 175531, 3600, -54973, 600, 'Eastern Standard Time - Atikokan, Ontario and Southampton I, Nunavut'
         c.timezone 'America/Rankin_Inlet', 3769, 60, -331499, 3600, 'Central Time - central Nunavut'
         c.timezone 'America/Winnipeg', 2993, 60, -1943, 20, 'Central Time - Manitoba & west Ontario'
         c.timezone 'America/Rainy_River', 2923, 60, -2837, 30, 'Central Time - Rainy River & Fort Frances, Ontario'
-        c.timezone 'America/Cambridge_Bay', 1381, 20, -1261, 12, 'Central Time - west Nunavut'
         c.timezone 'America/Regina', 252, 5, -2093, 20, 'Central Standard Time - Saskatchewan - most locations'
         c.timezone 'America/Swift_Current', 3017, 60, -647, 6, 'Central Standard Time - Saskatchewan - midwest'
         c.timezone 'America/Edmonton', 1071, 20, -1702, 15, 'Mountain Time - Alberta, east British Columbia & west Saskatchewan'
+        c.timezone 'America/Cambridge_Bay', 24881, 360, -37819, 360, 'Mountain Time - west Nunavut'
         c.timezone 'America/Yellowknife', 1249, 20, -2287, 20, 'Mountain Time - central Northwest Territories'
         c.timezone 'America/Inuvik', 246059, 3600, -8023, 60, 'Mountain Time - west Northwest Territories'
         c.timezone 'America/Dawson_Creek', 1793, 30, -3607, 30, 'Mountain Standard Time - Dawson Creek & Fort Saint John, British Columbia'
@@ -205,7 +211,7 @@ module TZInfo
       end
       country 'CL', 'Chile' do |c|
         c.timezone 'America/Santiago', -669, 20, -212, 3, 'most locations'
-        c.timezone 'Pacific/Easter', -163, 6, -2189, 20, 'Easter Island & Sala y Gomez'
+        c.timezone 'Pacific/Easter', -543, 20, -3283, 30, 'Easter Island & Sala y Gomez'
       end
       country 'CM', 'Cameroon' do |c|
         c.timezone 'Africa/Douala', 81, 20, 97, 10
@@ -270,7 +276,7 @@ module TZInfo
         c.timezone 'Africa/El_Aaiun', 543, 20, -66, 5
       end
       country 'ER', 'Eritrea' do |c|
-        c.timezone 'Africa/Asmera', 46, 3, 2333, 60
+        c.timezone 'Africa/Asmara', 46, 3, 2333, 60
       end
       country 'ES', 'Spain' do |c|
         c.timezone 'Europe/Madrid', 202, 5, -221, 60, 'mainland'
@@ -294,8 +300,8 @@ module TZInfo
         c.timezone 'Pacific/Ponape', 209, 30, 9493, 60, 'Ponape (Pohnpei)'
         c.timezone 'Pacific/Kosrae', 319, 60, 9779, 60, 'Kosrae'
       end
-      country 'FO', 'Faeroe Islands' do |c|
-        c.timezone 'Atlantic/Faeroe', 3721, 60, -203, 30
+      country 'FO', 'Faroe Islands' do |c|
+        c.timezone 'Atlantic/Faroe', 3721, 60, -203, 30
       end
       country 'FR', 'France' do |c|
         c.timezone 'Europe/Paris', 733, 15, 7, 3
@@ -304,7 +310,7 @@ module TZInfo
         c.timezone 'Africa/Libreville', 23, 60, 189, 20
       end
       country 'GB', 'Britain (UK)' do |c|
-        c.timezone 'Europe/London', 2059, 40, -5, 16
+        c.timezone 'Europe/London', 6181, 120, -451, 3600
       end
       country 'GD', 'Grenada' do |c|
         c.timezone 'America/Grenada', 241, 20, -247, 4
@@ -392,7 +398,7 @@ module TZInfo
         c.timezone 'Europe/Isle_of_Man', 1083, 20, -67, 15
       end
       country 'IN', 'India' do |c|
-        c.timezone 'Asia/Calcutta', 338, 15, 2651, 30
+        c.timezone 'Asia/Kolkata', 338, 15, 2651, 30
       end
       country 'IO', 'British Indian Ocean Territory' do |c|
         c.timezone 'Indian/Chagos', -22, 3, 869, 12
@@ -505,6 +511,9 @@ module TZInfo
       country 'ME', 'Montenegro' do |c|
         c.timezone 'Europe/Podgorica', 1273, 30, 289, 15
       end
+      country 'MF', 'St Martin (French part)' do |c|
+        c.timezone 'America/Marigot', 271, 15, -757, 12
+      end
       country 'MG', 'Madagascar' do |c|
         c.timezone 'Indian/Antananarivo', -227, 12, 2851, 60
       end
@@ -713,8 +722,7 @@ module TZInfo
         c.timezone 'Europe/Ljubljana', 921, 20, 871, 60
       end
       country 'SJ', 'Svalbard & Jan Mayen' do |c|
-        c.timezone 'Arctic/Longyearbyen', 78, 1, 16, 1, 'Svalbard'
-        c.timezone 'Atlantic/Jan_Mayen', 4259, 60, -97, 12, 'Jan Mayen'
+        c.timezone 'Arctic/Longyearbyen', 78, 1, 16, 1
       end
       country 'SK', 'Slovakia' do |c|
         c.timezone 'Europe/Bratislava', 963, 20, 1027, 60
@@ -797,14 +805,14 @@ module TZInfo
       country 'UA', 'Ukraine' do |c|
         c.timezone 'Europe/Kiev', 1513, 30, 1831, 60, 'most locations'
         c.timezone 'Europe/Uzhgorod', 2917, 60, 223, 10, 'Ruthenia'
-        c.timezone 'Europe/Zaporozhye', 287, 6, 211, 6, 'Zaporozh\'ye, E Lugansk'
+        c.timezone 'Europe/Zaporozhye', 287, 6, 211, 6, 'Zaporozh\'ye, E Lugansk / Zaporizhia, E Luhansk'
         c.timezone 'Europe/Simferopol', 899, 20, 341, 10, 'central Crimea'
       end
       country 'UG', 'Uganda' do |c|
         c.timezone 'Africa/Kampala', 19, 60, 389, 12
       end
       country 'UM', 'US minor outlying islands' do |c|
-        c.timezone 'Pacific/Johnston', 17, 1, -337, 2, 'Johnston Atoll'
+        c.timezone 'Pacific/Johnston', 67, 4, -10171, 60, 'Johnston Atoll'
         c.timezone 'Pacific/Midway', 1693, 60, -5321, 30, 'Midway Islands'
         c.timezone 'Pacific/Wake', 1157, 60, 9997, 60, 'Wake Island'
       end
@@ -814,11 +822,13 @@ module TZInfo
         c.timezone 'America/Kentucky/Louisville', 9181, 240, -154367, 1800, 'Eastern Time - Kentucky - Louisville area'
         c.timezone 'America/Kentucky/Monticello', 132587, 3600, -101819, 1200, 'Eastern Time - Kentucky - Wayne County'
         c.timezone 'America/Indiana/Indianapolis', 23861, 600, -310169, 3600, 'Eastern Time - Indiana - most locations'
-        c.timezone 'America/Indiana/Marengo', 17269, 450, -310841, 3600, 'Eastern Time - Indiana - Crawford County'
+        c.timezone 'America/Indiana/Vincennes', 69619, 1800, -315103, 3600, 'Eastern Time - Indiana - Daviess, Dubois, Knox & Martin Counties'
         c.timezone 'America/Indiana/Knox', 9911, 240, -693, 8, 'Eastern Time - Indiana - Starke County'
+        c.timezone 'America/Indiana/Winamac', 29557, 720, -311771, 3600, 'Eastern Time - Indiana - Pulaski County'
+        c.timezone 'America/Indiana/Marengo', 17269, 450, -310841, 3600, 'Eastern Time - Indiana - Crawford County'
         c.timezone 'America/Indiana/Vevay', 34873, 900, -153121, 1800, 'Eastern Time - Indiana - Switzerland County'
         c.timezone 'America/Chicago', 837, 20, -1753, 20, 'Central Time'
-        c.timezone 'America/Indiana/Vincennes', 69619, 1800, -315103, 3600, 'Central Time - Indiana - Daviess, Dubois, Knox, Martin, Perry & Pulaski Counties'
+        c.timezone 'America/Indiana/Tell_City', 136631, 3600, -312341, 3600, 'Central Time - Indiana - Perry County'
         c.timezone 'America/Indiana/Petersburg', 138571, 3600, -314203, 3600, 'Central Time - Indiana - Pike County'
         c.timezone 'America/Menominee', 40597, 900, -105137, 1200, 'Central Time - Michigan - Dickinson, Gogebic, Iron & Menominee Counties'
         c.timezone 'America/North_Dakota/Center', 169619, 3600, -121559, 1200, 'Central Time - North Dakota - Oliver County'
@@ -858,7 +868,7 @@ module TZInfo
         c.timezone 'America/St_Thomas', 367, 20, -974, 15
       end
       country 'VN', 'Vietnam' do |c|
-        c.timezone 'Asia/Saigon', 43, 4, 320, 3
+        c.timezone 'Asia/Ho_Chi_Minh', 43, 4, 320, 3
       end
       country 'VU', 'Vanuatu' do |c|
         c.timezone 'Pacific/Efate', -53, 3, 2021, 12
