@@ -9,7 +9,8 @@ module TZInfo
       timezone 'Africa/Accra'
       timezone 'Africa/Addis_Ababa'
       timezone 'Africa/Algiers'
-      timezone 'Africa/Asmera'
+      timezone 'Africa/Asmara'
+      linked_timezone 'Africa/Asmera'
       timezone 'Africa/Bamako'
       timezone 'Africa/Bangui'
       timezone 'Africa/Banjul'
@@ -71,6 +72,7 @@ module TZInfo
       timezone 'America/Argentina/Mendoza'
       timezone 'America/Argentina/Rio_Gallegos'
       timezone 'America/Argentina/San_Juan'
+      timezone 'America/Argentina/San_Luis'
       timezone 'America/Argentina/Tucuman'
       timezone 'America/Argentina/Ushuaia'
       timezone 'America/Aruba'
@@ -128,8 +130,10 @@ module TZInfo
       timezone 'America/Indiana/Knox'
       timezone 'America/Indiana/Marengo'
       timezone 'America/Indiana/Petersburg'
+      timezone 'America/Indiana/Tell_City'
       timezone 'America/Indiana/Vevay'
       timezone 'America/Indiana/Vincennes'
+      timezone 'America/Indiana/Winamac'
       linked_timezone 'America/Indianapolis'
       timezone 'America/Inuvik'
       timezone 'America/Iqaluit'
@@ -146,6 +150,7 @@ module TZInfo
       timezone 'America/Maceio'
       timezone 'America/Managua'
       timezone 'America/Manaus'
+      linked_timezone 'America/Marigot'
       timezone 'America/Martinique'
       timezone 'America/Mazatlan'
       linked_timezone 'America/Mendoza'
@@ -178,6 +183,7 @@ module TZInfo
       timezone 'America/Rankin_Inlet'
       timezone 'America/Recife'
       timezone 'America/Regina'
+      timezone 'America/Resolute'
       timezone 'America/Rio_Branco'
       linked_timezone 'America/Rosario'
       timezone 'America/Santiago'
@@ -185,6 +191,7 @@ module TZInfo
       timezone 'America/Sao_Paulo'
       timezone 'America/Scoresbysund'
       linked_timezone 'America/Shiprock'
+      linked_timezone 'America/St_Barthelemy'
       timezone 'America/St_Johns'
       timezone 'America/St_Kitts'
       timezone 'America/St_Lucia'
@@ -229,7 +236,7 @@ module TZInfo
       timezone 'Asia/Beirut'
       timezone 'Asia/Bishkek'
       timezone 'Asia/Brunei'
-      timezone 'Asia/Calcutta'
+      linked_timezone 'Asia/Calcutta'
       timezone 'Asia/Choibalsan'
       timezone 'Asia/Chongqing'
       linked_timezone 'Asia/Chungking'
@@ -242,6 +249,7 @@ module TZInfo
       timezone 'Asia/Dushanbe'
       timezone 'Asia/Gaza'
       timezone 'Asia/Harbin'
+      timezone 'Asia/Ho_Chi_Minh'
       timezone 'Asia/Hong_Kong'
       timezone 'Asia/Hovd'
       timezone 'Asia/Irkutsk'
@@ -254,6 +262,7 @@ module TZInfo
       timezone 'Asia/Karachi'
       timezone 'Asia/Kashgar'
       timezone 'Asia/Katmandu'
+      timezone 'Asia/Kolkata'
       timezone 'Asia/Krasnoyarsk'
       timezone 'Asia/Kuala_Lumpur'
       timezone 'Asia/Kuching'
@@ -278,7 +287,7 @@ module TZInfo
       timezone 'Asia/Riyadh87'
       timezone 'Asia/Riyadh88'
       timezone 'Asia/Riyadh89'
-      timezone 'Asia/Saigon'
+      linked_timezone 'Asia/Saigon'
       timezone 'Asia/Sakhalin'
       timezone 'Asia/Samarkand'
       timezone 'Asia/Seoul'
@@ -305,7 +314,8 @@ module TZInfo
       timezone 'Atlantic/Bermuda'
       timezone 'Atlantic/Canary'
       timezone 'Atlantic/Cape_Verde'
-      timezone 'Atlantic/Faeroe'
+      linked_timezone 'Atlantic/Faeroe'
+      timezone 'Atlantic/Faroe'
       linked_timezone 'Atlantic/Jan_Mayen'
       timezone 'Atlantic/Madeira'
       timezone 'Atlantic/Reykjavik'
@@ -319,6 +329,7 @@ module TZInfo
       linked_timezone 'Australia/Canberra'
       timezone 'Australia/Currie'
       timezone 'Australia/Darwin'
+      timezone 'Australia/Eucla'
       timezone 'Australia/Hobart'
       linked_timezone 'Australia/LHI'
       timezone 'Australia/Lindeman'
