@@ -195,8 +195,8 @@ class TCTimezone < Test::Unit::TestCase
   def test_all_country_zones
     # Probably should relax this test - just need all the zones, don't care
     # about order.
-    expected = Country.all.inject([]) {|expected,country|
-      expected += country.zones
+    expected = Country.all.inject([]) {|result,country|
+      result += country.zones
     }
     expected.uniq!
     
@@ -215,8 +215,8 @@ class TCTimezone < Test::Unit::TestCase
   def test_all_country_zone_identifiers
     # Probably should relax this test - just need all the zones, don't care
     # about order.
-    expected = Country.all.inject([]) {|expected,country|
-      expected += country.zone_identifiers
+    expected = Country.all.inject([]) {|result,country|
+      result += country.zone_identifiers
     }
     expected.uniq!
         
@@ -781,14 +781,14 @@ class TCTimezone < Test::Unit::TestCase
     assert_equal(true, TestTimezone.new('Europe/London') == TestTimezone.new('Europe/London'))
     assert_equal(false, TestTimezone.new('Europe/London') == TestTimezone.new('Europe/london'))
     assert_equal(false, TestTimezone.new('Europe/London') == TestTimezone.new('Europe/Paris'))
-    assert_nil(TestTimezone.new('Europe/London') == Object.new)
+    assert(!(TestTimezone.new('Europe/London') == Object.new))
   end
   
   def test_eql
     assert_equal(true, TestTimezone.new('Europe/London').eql?(TestTimezone.new('Europe/London')))
     assert_equal(false, TestTimezone.new('Europe/London').eql?(TestTimezone.new('Europe/london')))
     assert_equal(false, TestTimezone.new('Europe/London').eql?(TestTimezone.new('Europe/Paris')))
-    assert_nil(TestTimezone.new('Europe/London') == Object.new)
+    assert(!TestTimezone.new('Europe/London').eql?(Object.new))
   end
   
   def test_hash
